@@ -24,9 +24,25 @@ class DiceLoss(nn.Module):
 
     Parameters
     ----------
-    eps : float
+    eps : `float <https://docs.python.org/3/library/functions.html#float>`_
         epsilon
 
+    Examples
+    --------
+    >>> criterion = DiceLoss()
+    >>> predicted = torch.ones(2, 1, 32, 32)
+    >>> target = torch.ones(2, 1, 32, 32)
+    >>> loss = criterion(predicted, target)
+    >>> loss.item()
+    0.0
+
+    >>> criterion = DiceLoss()
+    >>> predicted = torch.ones(2, 1, 32, 32)
+    >>> target = torch.zeros(2, 1, 32, 32)
+    >>> loss = criterion(predicted, target)
+    >>> loss.item()
+    1.0
+
     References
     ----------
     https://www.kaggle.com/bigironsphere/loss-function-library-keras-pytorch
@@ -44,14 +60,14 @@ class DiceLoss(nn.Module):
 
         Parameters
         ----------
-        predicted : torch.Tensor
+        predicted : `torch.Tensor <https://pytorch.org/docs/stable/tensors.html#torch.Tensor>`_
             Predicted output tensor from a model.
-        target : torch.Tensor
+        target : `torch.Tensor <https://pytorch.org/docs/stable/tensors.html#torch.Tensor>`_
             Ground truth tensor.
 
         Returns
         -------
-        torch.Tensor
+        `torch.Tensor <https://pytorch.org/docs/stable/tensors.html#torch.Tensor>`_
             Dice loss computed between :attr:`predicted` and :attr:`target`.
 
         """
