@@ -1,5 +1,6 @@
 from .runner import Runner
+from .earlystop import EarlyStop
 from .scheduler import get_scheduler, set_scheduler
 from .optimizer import get_optimizer, set_optimizer
 
-__all__ = ['Runner','get_optimizer','set_optimizer','get_scheduler','set_scheduler']
+__all__ = ['Runner','get_optimizer','set_optimizer','get_scheduler','set_scheduler','EarlyStop']
